@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use PPI;
 
-our $VERSION = '0.30';
+our $VERSION = '0.32';
 
 
 
@@ -134,20 +134,23 @@ sub find_variable_declaration {
 	my $cursor   = shift;
 	return()
 	  if not $cursor or not $cursor->isa("PPI::Token");
+
 	my ($varname, $token_str);
 	if ($cursor->isa("PPI::Token::Symbol")) {
-		$varname = $cursor->canonical;
+		$varname = $cursor->symbol;
 		$token_str = $cursor->content;
 	}
 	else {
 		my $content = $cursor->content;
-		if ($content =~ /([\$@%*][\w:']+)/) {
+		if ($content =~ /((?:\$#?|[@%*])[\w:']+)/) {
 			$varname = $1;
 			$token_str = $1;
 		}
 	}
 	return()
 	  if not defined $varname;
+	
+	$varname =~ s/^\$\#/@/;
 
 	my $document = $cursor->top();
 	my $declaration;
@@ -181,7 +184,8 @@ sub find_variable_declaration {
 
 				if ($elem->isa("PPI::Token::Word") and $elem->content() =~ /^(?:my|our)$/) {
 					my $nelem = $elem->snext_sibling();
-					if (defined $nelem and $nelem->isa("PPI::Token::Symbol")) {
+					if (defined $nelem and $nelem->isa("PPI::Token::Symbol")
+					    and $nelem->symbol() eq $varname || $nelem->content() eq $token_str) {
 						$declaration = $nelem;
 						last;
 					}
